ParticipantIdGeneratorCollection

Struct ParticipantIdGeneratorCollection 

pub struct ParticipantIdGeneratorCollection<'a, 'b, I: ShareIdentifier> {
    pub generators: &'a [ParticipantIdGenerator<'b, I>],
}
A collection of participant number generators

Fields

generators: &'a [ParticipantIdGenerator<'b, I>]

The collection of participant ID generators

Implementations

Source

impl<'a, 'b, I: ShareIdentifier> ParticipantIdGeneratorCollection<'a, 'b, I>

pub fn iter(&self) -> impl Iterator<Item = I> + '_

Returns an iterator that generates participant identifiers.

The iterator will halt if an internal error occurs or an identifier is generated that is the zero element.